@@ -11,7 +11,6 @@ Project location : https://github.com/areski/python-nvd3
 
 from optparse import OptionParser
 from string import Template
-import random
 import json
 
 template_page_nvd3 = """
@@ -125,6 +124,7 @@ class NVD3Chart:
     tag_script_js = True
     charttooltip_dateformat = None
     x_axis_format = ''
+    show_legend = True
 
     header_css = ['http://nvd3.org/src/nv.d3.css']
     header_js = ['http://nvd3.org/lib/d3.v2.js', 'http://nvd3.org/nv.d3.js']
@@ -156,17 +156,19 @@ class NVD3Chart:
         if 'resize' in kwargs and kwargs["resize"]:
             self.resize = True
 
+        self.show_legend = kwargs.get("show_legend", True)
+
     def add_serie(self, y, x, name=None, extra={}, **kwargs):
         """
         add serie - Series are list of data that will be plotted
         y {1, 2, 3, 4, 5} / x {1, 2, 3, 4, 5}
+
+        TODO: Add doc for supported parameters, ie x_axis_date, shape, size
+
         """
         if not name:
             name = "Serie %d" % (len(self.series) + 1)
 
-        if self.x_axis_date:
-            x = [str(d) for d in x]
-
         # For scatterChart shape & size fields are added in serie
         if 'shape' in kwargs or 'size' in kwargs:
             if 'size' in kwargs and kwargs["size"]:
@@ -177,12 +179,12 @@ class NVD3Chart:
                 cshape = kwargs["shape"]
             else:
                 cshape = "circle"
-            serie =[{
+            serie = [{
                 "x": x[i],
                 "y": y,
                 "shape": cshape,
                 "size": csize[i] if isinstance(csize, list) else csize
-                } for i, y in enumerate(y)]
+            } for i, y in enumerate(y)]
         else:
             serie = [{"x": x[i], "y": y} for i, y in enumerate(y)]
 
@@ -387,6 +389,12 @@ class NVD3Chart:
         self.build_custom_tooltip()
         self.jschart += self.charttooltip
 
+        if self.model != 'discreteBarChart':
+            if self.show_legend:
+                self.jschart += stab(2) + "chart.showLegend(true)\n"
+            else:
+                self.jschart += stab(2) + "chart.showLegend(false)\n"
+
         #Inject data to D3
         self.jschart += stab(2) + "d3.select('#%s svg')\n" % self.name + \
             stab(3) + ".datum(%s)\n" % datum + \
